<?php

namespace Drupal\lightbox_media\Plugin\Field\FieldFormatter;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceEntityFormatter;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lightbox\LightboxFormatterTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'lightbox_media_container' formatter.
 */
#[FieldFormatter(
  id: 'lightbox_media_container',
  label: new TranslatableMarkup('Rendered entity in a lightbox container'),
  field_types: [
    'entity_reference',
  ],
)]
class LightboxMediaContainerFormatter extends EntityReferenceEntityFormatter {

  use LightboxFormatterTrait;
  use LightboxMediaContainerFormatterTrait;

  /**
   * The EntityField Manager service.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected EntityFieldManagerInterface $entityFieldManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->entityFieldManager = $container->get('entity_field.manager');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(FieldDefinitionInterface $field_definition) {
    // Formatter only available for entity types that reference media items.
    $field_storage_definition = $field_definition->getFieldStorageDefinition();
    return ($field_storage_definition->getSetting('target_type') == 'media')
      && $field_storage_definition->isMultiple();
  }

}
